@@ -39,7 +39,7 @@
 using namespace magics;
 
 
-ViewNode::ViewNode() : viewTransformation_(0), animation_("basic"), vaxis_(2.), haxis_(1.),  rules_(0), legend_(0)
+ViewNode::ViewNode() : viewTransformation_(0), animation_("basic"), vaxis_(2.), haxis_(1.),  rules_(0), legend_(0), needLegend_(false)
 {
 	static int i = 0;
 	ostringstream n;
@@ -68,6 +68,7 @@ void ViewNode::text(TextVisitor* text)
 void ViewNode::legend(LegendVisitor* legend)
 {
 	legend_ = legend;
+	needLegend_ = true;
 }
 
 void ViewNode::visit(MetaDataVisitor& metadata)
@@ -169,6 +170,7 @@ void ViewNode::prepareLayout(SceneLayer& tree)
 	frameHelper_->heightResolution(heightResolution()*width/100);
 
 	frameHelper_->frame(*layout_);
+	frameHelper_->blankIt();
 	frameHelper_->frameIt();
 	frameHelper_->clippIt(false);
 
@@ -179,14 +181,16 @@ void ViewNode::prepareLayout(SceneLayer& tree)
 
 	// Then the axis!
 	leftAxis_ = new LeftAxisVisitor(*drawing_);
-		leftAxis_->width(vaxis);
-		leftAxis_->frameIt();
+	leftAxis_->width(vaxis);
+	leftAxis_->frameIt();
+	
 	components_.push_back(leftAxis_);
 	helper.attachLeft(leftAxis_);
 
 	rightAxis_ = new RightAxisVisitor(*drawing_);
-		rightAxis_->width(vaxis);
-		rightAxis_->frameIt();
+	rightAxis_->width(vaxis);
+	rightAxis_->frameIt();
+	
 	helper.attachRight(rightAxis_);
 	components_.push_back(rightAxis_);
 
@@ -197,23 +201,25 @@ void ViewNode::prepareLayout(SceneLayer& tree)
 	topAxis_ = new TopAxisVisitor(*drawing_);
 	topAxis_->height(topaxis);
 	topAxis_->frameIt();
+	
 	helper.attachTop(topAxis_);
 	components_.push_back(topAxis_);
 	helper.add(topAxis_);
 
 
-
 	bottomAxis_ = new BottomAxisVisitor(*drawing_);
-		bottomAxis_->height(bottomaxis);
-		bottomAxis_->frameIt();
+	bottomAxis_->height(bottomaxis);
+	bottomAxis_->frameIt();
+	
 	components_.push_back(bottomAxis_);
 	helper.attachBottom(bottomAxis_);
 	helper.add(leftAxis_);
 	helper.add(rightAxis_);
 		
-	if ( legend_)
+	
+	tree.legend(legend_);
+	if ( needLegend_ && legend_ )
 	{
-		tree.legend(legend_);
 		if ( !legend_->positional() ) {
 			if ( legend_->top() ) {
 				legend_->height(5);
@@ -230,10 +236,13 @@ void ViewNode::prepareLayout(SceneLayer& tree)
 			helper.add(legend_);
 		}
 		((BasicSceneObject*)legend_)->parent((BasicSceneObject*)this);
-		legend_->getReady();
-
-		components_.push_back(legend_);
+	    legend_->getReady();
+	    components_.push_back(legend_);
 	}
+	else 
+		needLegend_ = false;
+   
+	
 
 	for (vector<TextVisitor*>::iterator text = texts_.begin(); text != texts_.end(); ++text)
 	{
@@ -285,27 +294,27 @@ void ViewNode::visit(SceneLayer& tree)
 
 	tree.rules(rules_);
 	// Here we checkeing for the legend!
-	bool legend = false;
+	needLegend_ = false;
 	for ( vector<BasicSceneObject*>::iterator item = items_.begin(); item != items_.end(); ++item)  {
-			legend = (*item)->needLegend();
-			if ( legend ) break;
+			needLegend_ = (*item)->needLegend();
+			if ( needLegend_ ) break;
 	}
 
-	if ( !legend ) {
-		legend_ = 0;
-	}
+	
 	
 	//Here we have the steps! 	
 	prepareLayout(tree);	
+	
 	if ( items_.empty() )
 	{
 		push_back(new EmptySceneObject() );
 	}
-	if (legend_) {
-	for ( vector<BasicSceneObject*>::iterator item = items_.begin(); item != items_.end(); ++item)  {
-		(*item)->getReady(*legend_);
-	}
+	if ( needLegend_ ) {
+		for ( vector<BasicSceneObject*>::iterator item = items_.begin(); item != items_.end(); ++item)  {
+			(*item)->getReady(*legend_);
+		}
 	}
+
 	for ( vector<BasicSceneObject*>::iterator item = items_.begin(); item != items_.end(); ++item)  {
 		(*item)->visit(tree, components_);
 	}
@@ -440,7 +449,7 @@ void XmlViewNode::getReady()
 	layout_->height(height.percent());
 	
 	layout_->display(display_);	
-	layout_->frame(true, border_, *border_colour_, border_style_, border_thickness_);
+	layout_->frame(true, border_, *border_colour_, border_style_, border_thickness_, *background_);
 
 	BasicSceneObject::getReady();
 }
@@ -555,8 +564,11 @@ void FortranViewNode::getReady()
 	ASSERT (parent_);
 
 	if ( predefined_ ) {
-			StyleLibrary library("projections");
-			const map<string, string>& area = library.get(predefined_name_);
+			MagDefLibrary library("projections");
+
+			MagDef::Definition area;
+
+			library.find(predefined_name_, area);
 			
 			viewTransformation_ = MagTranslator<string, Transformation>()(area.find("subpage_map_projection")->second);
 			viewTransformation_->set(area);
@@ -619,7 +631,7 @@ void FortranViewNode::getReady()
 	ParameterManager::set("subpage_x_position_internal", absx);
 	ParameterManager::set("subpage_y_position_internal", absy);
 
-	layout_->frame(true, frame_, *frame_colour_, frame_line_style_, frame_thickness_);
+	layout_->frame(true, frame_, *frame_colour_, frame_line_style_, frame_thickness_, *background_);
 	layout_->clippIt(clipping_);
 
 	BasicSceneObject::getReady();
