@@ -160,7 +160,8 @@ void LayoutFrame::blank(Layout& owner)
 	frame->setThickness(thickness_);
 	frame->setColour(visible_ ? colour_ : Colour("none"));
 	frame->setFilled(true);      
-	frame->setFillColour(Colour("white"));      
+	frame->setFillColour(background_);     
+
 		
 	FillShadingProperties* shading = new FillShadingProperties();          
 
@@ -185,6 +186,14 @@ void LayoutFrame::frame(Layout& owner)
 	frame->setThickness(thickness_);
 	frame->setColour(colour_); 
 
+	//frame->setFilled(true);      
+	//frame->setFillColour(background_);     
+
+	
+	FillShadingProperties* shading = new FillShadingProperties();          
+
+	//frame->setShading(shading);
+		
 	double px = (owner.maxX() - owner.minX())*0.00;
 	double py = (owner.maxY() - owner.minY())*0.00;
 	
